FeeLineTax class

Constructors

FeeLineTax(int? id, String? rateCode, String? rateId, String? label, bool? compound, String? taxTotal, String? shippingTaxTotal, List<MetaData>? metaData)
FeeLineTax.fromJson(Map<String, dynamic> json)

Properties

compound ↔ bool?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ int?
getter/setter pair
label ↔ String?
getter/setter pair
metaData ↔ List<MetaData>?
getter/setter pair
rateCode ↔ String?
getter/setter pair
rateId ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shippingTaxTotal ↔ String?
getter/setter pair
taxTotal ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited