Shipping class

Constructors

Shipping({String? firstName, String? lastName, String? company, String? address1, String? address2, String? city, String? state, String? postcode, String? country})
Shipping.fromJson(Map<String, dynamic> json)

Properties

address1 ↔ String?
getter/setter pair
address2 ↔ String?
getter/setter pair
city ↔ String?
getter/setter pair
company ↔ String?
getter/setter pair
country ↔ String?
getter/setter pair
firstName ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lastName ↔ String?
getter/setter pair
postcode ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited