WooShippingZoneMethod class

Constructors

WooShippingZoneMethod({int? instanceId, String? title, int? order, bool? enabled, String? methodId, String? methodTitle, String? methodDescription, WooShippingZoneMethodSettings? settings, WooShippingZoneMethodLinks? links})
WooShippingZoneMethod.fromJson(Map<String, dynamic> json)

Properties

enabled ↔ bool?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
instanceId ↔ int?
getter/setter pair
getter/setter pair
methodDescription ↔ String?
getter/setter pair
methodId ↔ String?
getter/setter pair
methodTitle ↔ String?
getter/setter pair
order ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
settings ↔ WooShippingZoneMethodSettings?
getter/setter pair
title ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited