WooShippingZoneMethodClassCosts class

Constructors

WooShippingZoneMethodClassCosts({String? id, String? label, String? description, String? type, String? value, String? classCostsDefault, String? tip, String? placeholder})
WooShippingZoneMethodClassCosts.fromJson(Map<String, dynamic> json)

Properties

classCostsDefault ↔ String?
getter/setter pair
description ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
getter/setter pair
label ↔ String?
getter/setter pair
placeholder ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tip ↔ String?
getter/setter pair
type ↔ String?
getter/setter pair
value ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited